@@ -1,6 +1,6 @@
 import urllib.parse
 
-from requests import get,exceptions,codes,Session
+from requests import exceptions,codes,Session
 from requests.auth import HTTPBasicAuth,AuthBase
 from requests.adapters import HTTPAdapter, Retry
 from requests.exceptions import ConnectionError, ConnectTimeout
@@ -68,6 +68,39 @@ class RestCall(Logger):
 
         #self._session.headers.update({'Authorization': self._auth})
 
+    def post(self, url = "",params:dict={},header:dict={}):
+        try:
+            if len(url) > 0 and url[0] != '/':
+                url=f'/{url}'
+            u = urllib.parse.quote(f'{self._base_url}{url}',safe='/:&?=')
+
+            #header = {}
+            if self._accept_json:
+                header['Accept']='application/json'
+            resp = self._session.post(u,params, timeout = (5, 15),auth=self._auth,headers=header)
+
+            resp.raise_for_status()
+
+            if resp.status_code == codes.ok:
+                return resp.status_code, resp.json()
+            else:
+                return resp.status_code,""
+            
+        except exceptions.ConnectionError as ex:
+            self.error(f'Unable to connect to host {self._base_url} ({ex})')
+        except exceptions.Timeout as ex:
+            #TODO Maybe set up for a retry, or continue in a retry loop
+            self.error(f'Timeout while performing api request using: {url} ({ex})')
+        except exceptions.TooManyRedirects as ex:
+            #TODO Tell the user their URL was bad and try a different one
+            self.error(f'TooManyRedirects while performing api request using: {url} ({ex})')
+        except exceptions.HTTPError as e:
+            self.error(e)
+        except exceptions.RequestException as e:
+            # catastrophic error. bail.
+            self.error(f'General Request exception while performing api request using: {u} ({e})')
+            raise e
+
 
     def get(self, url = "",header=None):
         start_dttm = ctime()
@@ -116,5 +149,6 @@ class RestCall(Logger):
         except exceptions.RequestException as e:
             # catastrophic error. bail.
             self.error(f'General Request exception while performing api request using: {u} ({e})')
+            raise e
 
         return 0, "{}"
